import superagentPromise from 'superagent-promise';
import _superagent from 'superagent';
import configStore from '../stores/ConfigStore'
import { request } from 'http';

const superagent = superagentPromise(_superagent, global.Promise);

const encode = encodeURIComponent;

const handleErrors = err => {
  if (err && err.response && err.response.status === 401) {
    // login out ?
  }
  return err;
};

const responseBody = res => (res.body || JSON.parse(res.text));

const tokenPlugin = req => {
  if (configStore.config.token) {
    req.set('authorization', `bearer ${configStore.config.token}`);
  }
};

const getUrl = (url, version) => {
  return `${configStore.config.apiRoot}/${version ? version : configStore.config.apiVersion}${url}`
}

const requests = {
  get: (url, version) =>
    superagent
      .get(getUrl(url, version))
      .use(tokenPlugin)
      .end(handleErrors)
      .then(responseBody),
  post: (url, body, version) =>
    superagent
      .post(getUrl(url, version), body)
      .use(tokenPlugin)
      .end(handleErrors)
      .then(responseBody),
};

const UserCard = {
  getUserInfo: () => requests.get(
    '/account/getCurrentAccountCard', 
    'v1.0.0'
  ),
  uploadIcon: (blob) => requests.post(
    '/file/upload/icon',
    {
      body: blob
    },
    'v1.0.0'
  ),
  updateNickName: (name) => requests.post('/sdm/authAccount.modify',{
    nickName: name
  },
  'v1.0.0'),
  updateSign: (sign) => requests.post('/sdm/signature',{
    content: sign
  },
  'v1.0.0')
}

const Holiday = {
  getHolidayList: ()=>requests.get(
    '/holiday/applyList', 
    'v1.0.0'
  )
}

const Favorite = {
  getAllList: (pageSize,pageNo,keywords)=>requests.post(
    '/search/favor/favorAll',
     {keywords: keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: pageSize,
        pageNo: pageNo
      }
    },
    'v1.0.0'
  ),
  getTopicList: (pageSize,pageNo,keywords)=>requests.post(
    '/imsv/search/mine/favorite/quan',
     {keywords: keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: pageSize,
        pageNo: pageNo
      }
    },
    'v1.0.0'
  ),
  getNewsList: (pageSize,pageNo,keywords)=>requests.post(
    '/imsv/search/mine/favorite/cms',
     {keywords: keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: pageSize,
        pageNo: pageNo
      }
    },
    'v1.0.0'
  ),
  getMessageList: (pageSize,pageNo,keywords)=>requests.post(
    '/search/favor/favorMess',
     {keywords: keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: pageSize,
        pageNo: pageNo
      }
    },
    'v1.0.0'
  ),
  cancelImFavorite: (articleId) => requests.post(
    `/webapi/message/favorite/${articleId}/no`, {},
    'v1.0.0'
  ),
  cancelCmsFavorite: (articleId, cancelType) => requests.post(
    '/webapi/commonFavorite/set',
     {id: articleId, 
      type: cancelType, 
    },
    'v1.0.0'
  )
}

const Integral = {
  getIntegral: ()=>requests.get(
    '/points/mine/get', 
    'v1.0.0'
  ),
  getAIIntegral: ()=>requests.get(
    '/points/mine/get', 
    'v1.0.0'
  ),
  getStoreUrl: surl => requests.get(
    '/points/ssoLogin/callback',
    'v1.0.0'
  )
}

export default {
  UserCard,
  Holiday,
  Integral,
  Favorite
};
