import React, {Component} from 'react'
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import tost, {errorTost} from "kara-module-tost"
import Modal from 'react-modal-plugin'
import 'kara-module-tost/lib/index.css'

class ColleagueComponent extends Component {
  constructor(props) {
    super(props)
    this.state = {
      showForwardModal: false,
      shareParams: {},
      height: 'auto'
    }
    this.container = React.createRef()
  }

  componentDidMount() {
    if (this.state.height === 'auto' && this.container.current) {
      this.setState({height: this.container.current.offsetHeight})
    }
  }

  getIconType = (fileType) => {
    let className = 'kuc-iconfont '
    if (fileType.toLowerCase() === 'rar' || fileType.toLowerCase() === 'zip') {
      className += 'kuc-zip s-zip'
    }
    else if (fileType === 'ppt' || fileType === 'pptx') {
      className += 'kuc-ppt s-ppt'
    }
    else if (fileType === 'xls' || fileType === 'xlsx') {
      className += 'kuc-excel s-excel'
    }
    else if (fileType === 'doc' || fileType === 'docx') {
      className += 'kuc-word s-word'
    }
    else {
      className += 'kuc-other s-file'
    }
    return className
  }
  cancelFavorite = (id, type) => {
    this.props.httpAgent.post(`/webapi/commonFavorite/set`, {
      id: id,
      type: type,
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          tost({type: 'success', msg: '取消收藏成功', time: 4})
          this.props.cancelCmsFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type: 'error', msg: '取消收藏失败', time: 4})
        }
      }
    )
  }
  modalForwardShow = (info) => {
    this.setState({showForwardModal: true})
    this.setState({
      shareParams: {
        title: "#"+info.topicName+"#",
        description: info.summary,
        thumbUrl: info.topicIcon,
        url: `${this.props.apiForward}/${info.topicName}`
      }
    })
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }

  onItemClick = () => {
    tost({type: 'success', msg: '暂不支持，请前往移动端查看', time: 4})
  }

  render() {
    const {lang, karaui: {Forward}} = this.props
    let fileAttr = this.props.fileAttr
    return (<div ref={this.container} className={`s-b-secondary ${css.colleagueContainer}`}
                 style={{height: fileAttr.canceled ? 0 : this.state.height}}>
      <ul className={css.ColleagueItem}>
        <li onClick={this.onItemClick}>#{fileAttr.sesFavoriteQuanTopicInfo.topicName}#</li>
        <li className='s-hint'>
          <span>{lang.source}&nbsp;{fileAttr.sesFavoriteQuanTopicInfo.createNickName}</span>
          <span>同事圈</span>
          <span>{fileAttr.sesFavoriteQuanTopicInfo.commentCount}&nbsp;评论</span>
          <span>{DataUtil.DateShow(fileAttr.sesFavoriteQuanTopicInfo.createTime)}</span>
          <span className={css.hoverShow} onClick={() => {
            this.modalForwardShow(fileAttr.sesFavoriteQuanTopicInfo)
          }}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
          <span className={css.hoverShow} onClick={() => {
            this.cancelFavorite(fileAttr.sesFavoriteQuanTopicInfo.quanTopicId, 'quan_topic')
          }}>
          <i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;{lang.cancelCollect}
        </span>
        </li>
      </ul>
      <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
        <Forward type='quan' httpAgent={this.props.httpAgent}
                 shareParams={this.state.shareParams}
                 modalHidden={this.modalForwardHide}/>
      </Modal>
    </div>)
  }
}

export default ColleagueComponent
